@@ -22,6 +22,7 @@ from .errors import UnexpectedKeyConfigurationException
 from .experiment import Channel, Experiment
 from .metric import MetricDefinition
 from .outcome import OutcomeSpec
+from .sql import generate_data_source_sql, generate_metrics_sql
 from .util import TemporaryDirectory
 
 OUTCOMES_DIR = "outcomes"
@@ -512,6 +513,33 @@ class ConfigCollection:
 
         return None
 
+    def get_metrics_sql(
+        self,
+        metrics: List[str],
+        platform: str,
+        group_by: List[str] = [],
+        where: Optional[str] = None,
+        group_by_client_id: bool = True,
+        group_by_submission_date: bool = True,
+    ) -> str:
+        """Generate a SQL query for the specified metrics."""
+        return generate_metrics_sql(
+            self,
+            metrics=metrics,
+            platform=platform,
+            group_by=group_by,
+            where=where,
+            group_by_client_id=group_by_client_id,
+            group_by_submission_date=group_by_submission_date,
+        )
+
+    def get_data_source_sql(
+        self, data_source: str, platform: str, where: Optional[str] = None
+    ) -> str:
+        return generate_data_source_sql(
+            self, data_source=data_source, platform=platform, where=where
+        )
+
     def get_env(self) -> jinja2.Environment:
         """
         Create a Jinja2 environment that understands the SQL agg_* helpers in mozanalysis.metrics.
