@@ -12,7 +12,7 @@ from metric_config_parser.metric import AnalysisPeriod
 from metric_config_parser.segment import Segment
 
 TEST_DIR = Path(__file__).parent
-DEFAULT_METRICS_CONFIG = TEST_DIR / "data" / "default_metrics.toml"
+DEFAULT_METRICS_CONFIG = TEST_DIR / "data" / "jetstream" / "defaults" / "firefox_desktop.toml"
 
 
 class TestExperimentSpec:
